@@ -1,4 +1,4 @@
 library(testthat)
 library(tidync)
 
-test_check("tidync")
+#test_check("tidync")
